๐Ÿ“Š ml_metrics

A lightweight and efficient Dart library for evaluating machine learning models.
Supports binary classification metrics such as Accuracy, Precision, Recall, F1 Score, and Confusion Matrix.


โœจ Features

  • โœ… Accuracy score
  • โœ… Precision & Recall (binary classification)
  • โœ… F1 Score
  • โœ… Confusion Matrix
  • โœ… Fully tested & null-safe

๐Ÿ“ฆ Installation

Add the following to your pubspec.yaml:

dependencies:
  ml_metrics: ^0.1.0

Then run:

dart pub get

๐Ÿš€ Quick Example

import 'package:ml_metrics/ml_metrics.dart';

void main() {
  final yTrue = [1, 0, 1, 1, 0];
  final yPred = [1, 0, 0, 1, 1];

  print('Accuracy: ${accuracy(yTrue, yPred)}');
  print('Precision: ${precision(yTrue, yPred)}');
  print('Recall: ${recall(yTrue, yPred)}');
  print('F1 Score: ${f1Score(yTrue, yPred)}');
  print('Confusion Matrix: ${binaryConfusionMatrix(yTrue, yPred)}');
}

๐Ÿ“š Metrics Reference

Metric Description
accuracy Ratio of correct predictions
precision TP / (TP + FP)
recall TP / (TP + FN)
f1Score Harmonic mean of precision and recall
binaryConfusionMatrix Returns TP, FP, FN, TN as a list

๐Ÿงช Run Tests

dart test


๐Ÿ“„ License

This project is licensed under the MIT License. See the LICENSE file for details.